==> advanced-clock-plugin_0.13.0.tar.gz: advanced-clock-plugin-0.13.0/status_area_plugin/usr/lib/advanced-clock-plugin/clocks/BinaryClock.py <==
#
# Copyright 2010 Ruediger Gad <r.c.g@gmx.de>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import cairo
from datetime import datetime
import gtk
import math

import clock

def get_name():
    return "Binary Clock"

class BinaryClock(clock.Clock):
    def draw_bits_horizontally(self, x, y, radius, value, n):
        for i in range(n):
            self.context.arc(x + (1.5 * radius) + (3 * radius * i), y + radius, radius, 0, 2 * math.pi)
            if (value >> (n - i - 1) & 1) > 0:
                self.context.fill_preserve()
            self.context.stroke()

    def draw_clock(self):
        if self.show_seconds :
            self.draw_bits_horizontally(12, 2, 4, self.time.hour, 5)
            self.draw_bits_horizontally(0, 14, 4, self.time.minute, 6)
            self.draw_bits_horizontally(0, 26, 4, self.time.second, 6)
        else :
            self.draw_bits_horizontally(18, 2, 6, self.time.hour, 5)
            self.draw_bits_horizontally(0, 20, 6, self.time.minute, 6)

    def resize(self):
        if self.show_seconds :
            self.drawing_area.set_size_request(76, 36)
        else:
            self.drawing_area.set_size_request(110, 36)

==> advanced-clock-plugin_0.14.4.tar.gz: advanced-clock-plugin-0.14.4/status_area_plugin/usr/lib/advanced-clock-plugin/clocks/BinaryClock.py <==
#
# Copyright 2010 Ruediger Gad <r.c.g@gmx.de>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import cairo
from datetime import datetime
import gtk
import math

import clock

def get_name():
    return "Binary Clock"

class BinaryClock(clock.Clock):
    def draw_bits_horizontally(self, x, y, radius, value, n):
        for i in range(n):
            self.context.arc(x + (1.5 * radius) + (3 * radius * i), y + radius, radius, 0, 2 * math.pi)
            if (value >> (n - i - 1) & 1) > 0:
                self.context.fill_preserve()
            self.context.stroke()

    def draw_clock(self):
        h = self.time.hour
        if self.twelve_hour_mode :
            abrv = 0
            if h == 0 :
                h = 12
            elif h == 12 :
                abrv = 1
            elif h > 12 :
                h = h % 12
                abrv = 1

        if self.show_seconds :
            if self.twelve_hour_mode :
                self.draw_bits_horizontally(24, 2, 4, h, 4)
                self.draw_bits_horizontally(0, 2, 4, abrv, 1)
            else :
                self.draw_bits_horizontally(12, 2, 4, h, 5)
            self.draw_bits_horizontally(0, 14, 4, self.time.minute, 6)
            self.draw_bits_horizontally(0, 26, 4, self.time.second, 6)
        else :
            if self.twelve_hour_mode :
                self.draw_bits_horizontally(36, 2, 6, h, 4)
                self.draw_bits_horizontally(0, 2, 6, abrv, 1)
            else :
                self.draw_bits_horizontally(18, 2, 6, h, 5)
            self.draw_bits_horizontally(0, 20, 6, self.time.minute, 6)

    def resize(self):
        if self.show_seconds :
            self.drawing_area.set_size_request(76, 36)
        else:
            self.drawing_area.set_size_request(110, 36)
